[![Gitter](https://badges.gitter.im/meren/anvio.svg)](https://gitter.im/meren/anvio?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

![anvio logo](http://merenlab.org/images/anvio-logo.png)

Please see the project page for installation and usage information: 

* [http://merenlab.org/software/anvio/](http://merenlab.org/software/anvio/)

# Others on anvi'o

* _"The greatest thing since sliced bread and Google Keep."_, [Sandra McLellan](http://home.freshwater.uwm.edu/mclellanlab/) ([17 Mar 2016](https://twitter.com/sandralmclellan/status/710520121282793473)).
* _"Anvio que llegue la noche uara verte brillar mas que las estrellas."_, [noa](https://twitter.com/gironaespnoa4) ([14 Jan 2016](https://twitter.com/gironaespnoa4/status/687702610221101056))
* _"I'm installing anvi'o on my old 2010 MacBook Pro. I'll let you know if it blows up."_, [Ryan Bartelme](https://twitter.com/microbialbart) ([19 Jan 2016](https://twitter.com/MicrobialBart/status/689540524714409984)) _(we like to assume it did not blow up since we have not heard from Mr. Bartelme)_.
